@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2008 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 
 extern int verbose;
 
-#define d(x) 
+#define d(x)
 #define v(x) if (verbose > 3) x;
 
 
@@ -59,14 +59,14 @@ random_whole_stream (const char *datadir, char **filename)
 	
 	/* read between 4k and 14k bytes */
 	size = 4096 + (size_t) (10240.0 * (rand () / (RAND_MAX + 1.0)));
-	v(fprintf (stdout, "Generating " SIZE_T " bytes of random data... ", size));
+	v(fprintf (stdout, "Generating %zu bytes of random data... ", size));
 	v(fflush (stdout));
 	
 	g_mkdir_with_parents (datadir, 0755);
 	
-	snprintf (buf, sizeof (buf), "%s%cstream.%u", datadir, G_DIR_SEPARATOR, getpid ());
+	g_snprintf (buf, sizeof (buf), "%s%cstream.%u", datadir, G_DIR_SEPARATOR, getpid ());
 	if ((fd = open (buf, O_CREAT | O_TRUNC | O_RDWR, 0666)) == -1) {
-		fprintf (stderr, "Error: Cannot create `%s': %s\n", buf, strerror (errno));
+		fprintf (stderr, "Error: Cannot create `%s': %s\n", buf, g_strerror (errno));
 		exit (EXIT_FAILURE);
 	}
 	
@@ -111,7 +111,7 @@ static int
 check_streams_match (GMimeStream *orig, GMimeStream *dup, const char *filename, int check_overflow)
 {
 	char buf[4096], dbuf[4096], errstr[1024];
-	size_t totalsize, totalread = 0;
+	gint64 len, totalsize, totalread = 0;
 	size_t nread, size;
 	ssize_t n;
 	
@@ -120,14 +120,14 @@ check_streams_match (GMimeStream *orig, GMimeStream *dup, const char *filename,
 	
 	if (orig->bound_end != -1) {
 		totalsize = orig->bound_end - orig->position;
-	} else if ((n = g_mime_stream_length (orig)) == -1) {
+	} else if ((len = g_mime_stream_length (orig)) == -1) {
 		sprintf (errstr, "Error: Unable to get length of original stream\n");
 		goto fail;
-	} else if (n < (orig->position - orig->bound_start)) {
+	} else if (len < (orig->position - orig->bound_start)) {
 		sprintf (errstr, "Error: Overflow on original stream?\n");
 		goto fail;
 	} else {
-		totalsize = n - (orig->position - orig->bound_start);
+		totalsize = len - (orig->position - orig->bound_start);
 	}
 	
 	while (totalread < totalsize) {
@@ -138,19 +138,19 @@ check_streams_match (GMimeStream *orig, GMimeStream *dup, const char *filename,
 		nread = 0;
 		totalread += n;
 		
-		d(fprintf (stderr, "read " SIZE_T " bytes from original stream\n", size));
+		d(fprintf (stderr, "read %zu bytes from original stream\n", size));
 		
 		do {
 			if ((n = g_mime_stream_read (dup, dbuf + nread, size - nread)) <= 0) {
-				d(fprintf (stderr, "dup read() returned " SSIZE_T ", EOF\n", n));
+				d(fprintf (stderr, "dup read() returned %zd, EOF\n", n));
 				break;
 			}
-			d(fprintf (stderr, "read " SSIZE_T " bytes from dup stream\n", n));
+			d(fprintf (stderr, "read %zd bytes from dup stream\n", n));
 			nread += n;
 		} while (nread < size);
 		
 		if (nread < size) {
-			sprintf (errstr, "Error: `%s' appears to be truncated, short %u+ bytes\n",
+			sprintf (errstr, "Error: `%s' appears to be truncated, short %zu+ bytes\n",
 				 filename, size - nread);
 			goto fail;
 		}
@@ -159,7 +159,7 @@ check_streams_match (GMimeStream *orig, GMimeStream *dup, const char *filename,
 			sprintf (errstr, "Error: `%s': content does not match\n", filename);
 			goto fail;
 		} else {
-			d(fprintf (stderr, SIZE_T " bytes identical\n", size));
+			d(fprintf (stderr, "%zu bytes identical\n", size));
 		}
 	}
 	
@@ -200,7 +200,7 @@ test_cat_write (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 			   part->filename, part->pstart, part->pend));
 		
 		if ((fd = open (part->filename, O_CREAT | O_TRUNC | O_WRONLY, 0666)) == -1) {
-			ex = exception_new ("could not create `%s': %s", part->filename, strerror (errno));
+			ex = exception_new ("could not create `%s': %s", part->filename, g_strerror (errno));
 			throw (ex);
 		}
 		
@@ -213,7 +213,7 @@ test_cat_write (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 	
 	g_mime_stream_reset (whole);
 	if (g_mime_stream_write_to_stream (whole, (GMimeStream *) cat) == -1) {
-		ex = exception_new ("%s", strerror (errno));
+		ex = exception_new ("%s", g_strerror (errno));
 		g_object_unref (cat);
 		throw (ex);
 	}
@@ -225,8 +225,8 @@ test_cat_write (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 	part = parts;
 	while (part != NULL) {
 		d(fprintf (stderr, "checking substream %s\n", part->filename));
-		if ((fd = open (part->filename, O_RDONLY)) == -1) {
-			ex = exception_new ("could not open `%s': %s", part->filename, strerror (errno));
+		if ((fd = open (part->filename, O_RDONLY, 0)) == -1) {
+			ex = exception_new ("could not open `%s': %s", part->filename, g_strerror (errno));
 			throw (ex);
 		}
 		
@@ -271,8 +271,8 @@ test_cat_read (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 		d(fprintf (stderr, "adding %s start=%lld, end=%lld...\n",
 			   part->filename, part->pstart, part->pend));
 		
-		if ((fd = open (part->filename, O_RDONLY)) == -1) {
-			ex = exception_new ("could not open `%s': %s", part->filename, strerror (errno));
+		if ((fd = open (part->filename, O_RDONLY, 0)) == -1) {
+			ex = exception_new ("could not open `%s': %s", part->filename, g_strerror (errno));
 			g_object_unref (cat);
 			throw (ex);
 		}
@@ -297,19 +297,15 @@ test_cat_seek (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 {
 	struct _StreamPart *part = parts;
 	GMimeStream *stream, *cat;
+	gint64 offset, len;
 	Exception *ex;
-	gint64 offset;
-	size_t size;
-	ssize_t n;
 	int fd;
 	
 	if (whole->bound_end != -1) {
-		size = whole->bound_end - whole->bound_start;
-	} else if ((n = g_mime_stream_length (whole)) == -1) {
+		len = whole->bound_end - whole->bound_start;
+	} else if ((len = g_mime_stream_length (whole)) == -1) {
 		ex = exception_new ("unable to get original stream length");
 		throw (ex);
-	} else {
-		size = n;
 	}
 	
 	cat = g_mime_stream_cat_new ();
@@ -318,8 +314,8 @@ test_cat_seek (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 		d(fprintf (stderr, "adding %s start=%lld, end=%lld...\n",
 			   part->filename, part->pstart, part->pend));
 		
-		if ((fd = open (part->filename, O_RDONLY)) == -1) {
-			ex = exception_new ("could not open `%s': %s", part->filename, strerror (errno));
+		if ((fd = open (part->filename, O_RDONLY, 0)) == -1) {
+			ex = exception_new ("could not open `%s': %s", part->filename, g_strerror (errno));
 			g_object_unref (cat);
 			throw (ex);
 		}
@@ -332,17 +328,17 @@ test_cat_seek (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 	}
 	
 	/* calculate a random seek offset to compare at */
-	offset = (gint64) (size * (rand () / (RAND_MAX + 1.0)));
+	offset = (gint64) (len * (rand () / (RAND_MAX + 1.0)));
 	
 	if (g_mime_stream_seek (whole, offset, GMIME_STREAM_SEEK_SET) == -1) {
 		ex = exception_new ("could not seek to %lld in original stream: %s",
-				    offset, strerror (errno));
+				    offset, g_strerror (errno));
 		throw (ex);
 	}
 	
 	if (g_mime_stream_seek (cat, offset, GMIME_STREAM_SEEK_SET) == -1) {
 		ex = exception_new ("could not seek to %lld: %s",
-				    offset, strerror (errno));
+				    offset, g_strerror (errno));
 		throw (ex);
 	}
 	
@@ -358,19 +354,15 @@ test_cat_substream (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 {
 	GMimeStream *stream, *cat, *sub1, *sub2;
 	struct _StreamPart *part = parts;
-	gint64 start, end;
+	gint64 start, end, len;
 	Exception *ex;
-	size_t size;
-	ssize_t n;
 	int fd;
 	
 	if (whole->bound_end != -1) {
-		size = whole->bound_end - whole->bound_start;
-	} else if ((n = g_mime_stream_length (whole)) == -1) {
+		len = whole->bound_end - whole->bound_start;
+	} else if ((len = g_mime_stream_length (whole)) == -1) {
 		ex = exception_new ("unable to get original stream length");
 		throw (ex);
-	} else {
-		size = n;
 	}
 	
 	cat = g_mime_stream_cat_new ();
@@ -379,8 +371,8 @@ test_cat_substream (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 		d(fprintf (stderr, "adding %s start=%lld, end=%lld...\n",
 			   part->filename, part->pstart, part->pend));
 		
-		if ((fd = open (part->filename, O_RDONLY)) == -1) {
-			ex = exception_new ("could not open `%s': %s", part->filename, strerror (errno));
+		if ((fd = open (part->filename, O_RDONLY, 0)) == -1) {
+			ex = exception_new ("could not open `%s': %s", part->filename, g_strerror (errno));
 			g_object_unref (cat);
 			throw (ex);
 		}
@@ -393,21 +385,21 @@ test_cat_substream (GMimeStream *whole, struct _StreamPart *parts, int bounded)
 	}
 	
 	/* calculate a random start/end offsets */
-	start = (gint64) (size * (rand () / (RAND_MAX + 1.0)));
+	start = (gint64) (len * (rand () / (RAND_MAX + 1.0)));
 	if (rand () % 2)
-		end = start + (gint64) ((size - start) * (rand () / (RAND_MAX + 1.0)));
+		end = start + (gint64) ((len - start) * (rand () / (RAND_MAX + 1.0)));
 	else
 		end = -1;
 	
 	if (!(sub1 = g_mime_stream_substream (whole, start, end))) {
 		ex = exception_new ("could not substream the original stream: %s",
-				    strerror (errno));
+				    g_strerror (errno));
 		g_object_unref (cat);
 		throw (ex);
 	}
 	
 	if (!(sub2 = g_mime_stream_substream (cat, start, end))) {
-		ex = exception_new ("%s", strerror (errno));
+		ex = exception_new ("%s", g_strerror (errno));
 		g_object_unref (sub1);
 		g_object_unref (cat);
 		throw (ex);
@@ -448,13 +440,13 @@ int main (int argc, char **argv)
 	const char *datadir = "data/cat";
 	struct _StreamPart *list, *tail, *n;
 	gboolean failed = FALSE;
-	ssize_t wholelen, left;
+	gint64 wholelen, left;
 	GMimeStream *whole;
 	guint32 part = 0;
 	gint64 start = 0;
 	char *filename;
 	struct stat st;
-	size_t len;
+	gint64 len;
 	int fd, i;
 	
 	srand (time (NULL));
@@ -482,7 +474,7 @@ int main (int argc, char **argv)
 		
 		if (S_ISREG (st.st_mode)) {
 			/* test a particular input file */
-			if ((fd = open (argv[i], O_RDONLY)) == -1)
+			if ((fd = open (argv[i], O_RDONLY, 0)) == -1)
 				return EXIT_FAILURE;
 			
 			filename = g_strdup (argv[i]);
@@ -512,7 +504,7 @@ int main (int argc, char **argv)
 	
 	left = wholelen;
 	while (left > 0) {
-		len = 1 + (size_t) (left * (rand() / (RAND_MAX + 1.0)));
+		len = 1 + (gint64) (left * (rand () / (RAND_MAX + 1.0)));
 		n = g_new (struct _StreamPart, 1);
 		sprintf (n->filename, "%s.%u", filename, part++);
 		n->pstart = (gint64) 0; /* FIXME: we could make this a random offset */
