@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2011 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -37,11 +37,12 @@
 #include "zentimer.h"
 #endif
 
-/*#define TEST_RAW_HEADER*/
+//#define TEST_RAW_HEADER
 #define TEST_PRESERVE_HEADERS
 #define PRINT_MIME_STRUCT
-/*#define TEST_WRITE_TO_STREAM*/
+//#define TEST_WRITE_TO_STREAM
 
+#ifdef PRINT_MIME_STRUCT
 static void
 print_depth (int depth)
 {
@@ -89,6 +90,71 @@ print_mime_struct (GMimeObject *part, int depth)
 	}
 }
 
+static void
+print_mime_part_info (const char *path, GMimeObject *object)
+{
+	const GMimeContentType *type;
+	gboolean has_md5;
+	
+	type = g_mime_object_get_content_type (object);
+	
+	if (GMIME_IS_PART (object))
+		has_md5 = g_mime_object_get_header (object, "Content-Md5") != NULL;
+	else
+		has_md5 = FALSE;
+	
+	fprintf (stdout, "%s\tContent-Type: %s/%s%s", path,
+		 type->type, type->subtype, has_md5 ? "; md5sum=" : "\n");
+	
+	if (has_md5) {
+		/* validate the Md5 sum */
+		if (g_mime_part_verify_content_md5 ((GMimePart *) object))
+			fprintf (stdout, "GOOD\n");
+		else
+			fprintf (stdout, "BAD\n");
+	}
+}
+
+static void
+print_mime_struct_iter (GMimeMessage *message)
+{
+	const char *jump_to = "4.2.2.2";
+	GMimePartIter *iter;
+	GMimeObject *part;
+	char *path;
+	
+	iter = g_mime_part_iter_new ((GMimeObject *) message);
+	if (g_mime_part_iter_is_valid (iter)) {
+		part = g_mime_part_iter_get_parent (iter);
+		print_mime_part_info ("TEXT", part);
+		
+		do {
+			part = g_mime_part_iter_get_current (iter);
+			path = g_mime_part_iter_get_path (iter);
+			print_mime_part_info (path, part);
+			g_free (path);
+		} while (g_mime_part_iter_next (iter));
+		
+#if 0
+		fprintf (stdout, "Jumping to %s\n", jump_to);
+		if (g_mime_part_iter_jump_to (iter, jump_to)) {
+			part = g_mime_part_iter_get_current (iter);
+			path = g_mime_part_iter_get_path (iter);
+			print_mime_part_info (path, part);
+			g_free (path);
+		} else {
+			fprintf (stdout, "Failed to jump to %s\n", jump_to);
+		}
+#endif
+	} else {
+		part = g_mime_message_get_mime_part (message);
+		print_mime_part_info ("TEXT", part);
+	}
+	
+	g_mime_part_iter_free (iter);
+}
+#endif /* PRINT_MIME_STRUCT */
+
 static void
 test_parser (GMimeStream *stream)
 {
@@ -119,7 +185,7 @@ test_parser (GMimeStream *stream)
 	{
 		char *raw;
 		
-		raw = g_mime_message_get_headers (message);
+		raw = g_mime_object_get_headers ((GMimeObject *) message);
 		fprintf (stdout, "\nTesting raw headers...\n\n%s\n", raw);
 		g_free (raw);
 	}
@@ -152,7 +218,8 @@ test_parser (GMimeStream *stream)
 	
 #ifdef PRINT_MIME_STRUCT
 	/* print mime structure */
-	print_mime_struct (message->mime_part, 0);
+	//print_mime_struct (message->mime_part, 0);
+	print_mime_struct_iter (message);
 #endif
 	
 	g_object_unref (message);
